==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_sk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Plugin %1 nie je kompatibilný s týmto systémom.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Pridať rozloženie klávesnice</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Dátum Čas</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-hodinový čas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-hodinový čas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Nastavenia času</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Povoliť sieť</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Zakázať sieť</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Nastavenia siete</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Naozaj chcete vyprázdniť %1 položky?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Túto akciu nemožno obnoviť</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Neznáme zariadenie</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Neznámy zväzok</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvoriť</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Odpojiť všetko</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Spúšťač</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Módny režim</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efektívny režim</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Hore</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dolu</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vľavo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Ponechať zobrazené</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Ponechať skryté</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Inteligentné skrývanie</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Režim</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Umiestnenie</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Pluginy</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Multitaskingový pohľad</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Odopnúť z panela</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Vypnúť káblové pripojenie</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Zapnúť káblové pripojenie</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Vypnúť bezdrôtové pripojenie</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Zapnúť bezdrôtové pripojenie</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Zakázať sieť</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Povoliť sieť</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Nastavenia siete</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Zariadenie zakázané</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Bezdrôtové pripojenie: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Káblové pripojenie: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nepripojené</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Pripájanie</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Pripojené, ale bez prístupu na internet</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Sieťový kábel odpojený</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Bezdrôtová sieť</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Drôtová sieť</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Sieť</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Drôtová sieť</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Káblová sieť %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavenia</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Napájanie</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Nastavenia napájania</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Nabíjanie %1, zostávajú %2 min</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Nabíjanie %1, zostáva %2 hod %3 min</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Nabíjanie %1, %2 min do plnej kapacity</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Nabíjanie %1, %2 hod %3 min do plnej kapacity</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Nabitý</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapacita %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Nabíjanie %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapacita %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapacita %1, plne nabité</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Zobraziť plochu</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Odopnúť z panela</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Napájanie</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspať</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernácia</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zamknúť</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odhlásiť</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Prepnúť používateľa</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Nastavenia napájania</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reštart</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Zariadenie</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Zrušiť stlmenie</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stlmiť</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Nastavenia zvuku</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Hlasitosť %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Kôš</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Kôš - %1 súbor</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Kôš - %1 súbory/súborov</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Otvoriť</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Vysypať</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Systémový panel</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Bezdrôtová sieť</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Bezdrôtová sieť %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.53.orig.tar.xz: dde-dock-5.5.53/translations/dde-dock_sk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Plugin %1 nie je kompatibilný s týmto systémom.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Pridať rozloženie klávesnice</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Dátum Čas</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-hodinový čas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-hodinový čas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Nastavenia času</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Naozaj chcete vyprázdniť %1 položky?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Túto akciu nemožno obnoviť</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Neznáme zariadenie</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Neznámy zväzok</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvoriť</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Odpojiť všetko</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Spúšťač</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Módny režim</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efektívny režim</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Hore</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dolu</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vľavo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Ponechať zobrazené</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Ponechať skryté</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Inteligentné skrývanie</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Režim</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Umiestnenie</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Pluginy</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show the Dock</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Multitaskingový pohľad</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Odopnúť z panela</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavenia</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Napájanie</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Nastavenia napájania</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Nabíjanie %1, zostávajú %2 min</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Nabíjanie %1, zostáva %2 hod %3 min</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Nabíjanie %1, %2 min do plnej kapacity</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Nabíjanie %1, %2 hod %3 min do plnej kapacity</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapacita %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Nabíjanie %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapacita %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapacita %1, plne nabité</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Zobraziť plochu</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Odopnúť z panela</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Napájanie</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspať</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernácia</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zamknúť</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odhlásiť</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Prepnúť používateľa</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Nastavenia napájania</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reštart</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Zariadenie</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Zrušiť stlmenie</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stlmiť</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Nastavenia zvuku</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Hlasitosť %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Kôš</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Kôš - %1 súbor</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Kôš - %1 súbory/súborov</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Presunúť do koša</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Otvoriť</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Vysypať</translation>
    </message>
</context>
</TS>
